.. _diffusion-poisson_short_syntax:

diffusion/poisson_short_syntax.py
=================================

**Description**


Laplace equation using the short syntax of keywords.

See :ref:`diffusion-poisson` for the long syntax version.

Find :math:`t` such that:

.. math::
    \int_{\Omega} c \nabla s \cdot \nabla t
    = 0
    \;, \quad \forall s \;.


.. image:: /../doc/images/gallery/diffusion-poisson_short_syntax.png


:download:`source code </../sfepy/examples/diffusion/poisson_short_syntax.py>`

.. literalinclude:: /../sfepy/examples/diffusion/poisson_short_syntax.py

